@@ -124,10 +124,6 @@ new_empty_col_sentinel <- function(type) {
 #'
 #' @keywords internal
 #' @export
-#' @examples
-#' long_string <- list(paste(letters, collapse = " "))
-#' squeeze(colonnade(long_string), width = 40)
-#' squeeze(colonnade(long_string), width = 20)
 squeeze <- function(x, width = NULL, ...) {
   deprecate_soft("1.5.0", "pillar::squeeze()")
 
@@ -245,8 +241,6 @@ knit_print_squeezed_colonnade_tier <- function(x) {
 #' @inheritParams ellipsis::dots_used
 #' @keywords internal
 #' @export
-#' @examples
-#' extra_cols(squeeze(colonnade(list(a = 1:3, b = 4:6), width = 8)))
 extra_cols <- function(x, ...) {
   deprecate_soft("1.5.0", "pillar::extra_cols()")
 
@@ -414,7 +408,7 @@ combine_pillar_distributions <- function(max_fit, min_fit_rev, tier_widths) {
   #' 3. We consult the column offsets. The last column where the minimum assignment
   #'    has a greater or equal offset than the maximum assignment is our latest
   #'    cut point.
-  cut_point_candidate_idx <- which(max_fit$offset[cut_point_candidates] <= min_fit_rev$offset[cut_point_candidates])
+  cut_point_candidate_idx <- which(max_fit$offset_after[cut_point_candidates] <= min_fit_rev$offset_after[cut_point_candidates])
   if (length(cut_point_candidate_idx) > 0) {
     cut_point <- cut_point_candidates[max(cut_point_candidate_idx)]
   } else {
@@ -435,7 +429,7 @@ combine_pillar_distributions <- function(max_fit, min_fit_rev, tier_widths) {
 #' @aliases NULL
 distribute_pillars <- function(widths, tier_widths) {
   tier <- rep(NA_integer_, length(widths))
-  offset <- rep(NA_integer_, length(widths))
+  offset_after <- rep(NA_integer_, length(widths))
   current_tier <- 1L
   current_x <- 0L
 
@@ -458,11 +452,11 @@ distribute_pillars <- function(widths, tier_widths) {
 
     tier[[i]] <- current_tier
     current_x <- current_x + widths[[i]]
-    offset[[i]] <- current_x
+    offset_after[[i]] <- current_x
     current_x <- current_x + 1L
   }
 
-  data_frame(id = seq_along(widths), width = widths, tier = tier, offset = offset)
+  data_frame(id = seq_along(widths), tier = tier, width = widths, offset_after = offset_after)
 }
 
 distribute_pillars_rev <- function(widths, tier_widths) {
@@ -474,41 +468,16 @@ distribute_pillars_rev <- function(widths, tier_widths) {
   splits <- unname(split(seq_along(tier), tier))
   tier_widths <- tier_widths[seq_along(splits)]
 
-  new_offset <- unlist(map2(splits, tier_widths, function(.x, .y) {
-    offsets <- ret$offset[.x]
-    new_offset <-  max(offsets) - offsets
-    new_offset - max(new_offset) + .y
+  new_offset_after <- unlist(map2(splits, tier_widths, function(.x, .y) {
+    new_offset_after <- cumsum(ret$width[.x] + 1)
+    new_offset_after - max(new_offset_after) + .y
   }))
 
-  ret$offset <- c(new_offset, rep(NA_integer_, sum(is.na(tier))))
+  ret$offset_after <- c(new_offset_after, rep(NA_integer_, sum(is.na(tier))))
 
   ret
 }
 
-distribute_pillars_offset <- function(widths, tier_widths,
-                                      widths_offset, tier_widths_offset) {
-  tier_widths <- tier_widths[seq2(tier_widths_offset, length(tier_widths))]
-  if (length(tier_widths) == 0) {
-    # Work around corner case
-    return(distribute_pillars(integer(), integer()))
-  }
-
-  widths <- widths[seq2(widths_offset, length(widths))]
-  fit_cut <- distribute_pillars(widths, tier_widths)
-  add_pillars_offset(fit_cut, widths_offset, tier_widths_offset)
-}
-
-add_pillars_offset <- function(fit_cut, widths_offset, tier_widths_offset) {
-  if (tier_widths_offset == 1) {
-    # Work around corner case
-    return(fit_cut)
-  }
-
-  fit_cut$id <- fit_cut$id + (widths_offset - 1L)
-  fit_cut$tier <- fit_cut$tier + (tier_widths_offset - 1L)
-  fit_cut
-}
-
 all_pillars_fit <- function(tier_df) {
   rows <- nrow(tier_df)
   rows == 0 || !safe_any_na(tier_df$tier[[nrow(tier_df)]])
